# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'form.ui'
#
# Created by: PyQt5 UI code generator 5.15.10
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(1128, 650)
        self.Widget = QtWidgets.QWidget(MainWindow)
        self.Widget.setObjectName("Widget")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.Widget)
        self.gridLayout_2.setSizeConstraint(QtWidgets.QLayout.SetMaximumSize)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setSizeConstraint(QtWidgets.QLayout.SetMaximumSize)
        self.verticalLayout.setContentsMargins(10, 10, -1, -1)
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setSizeConstraint(QtWidgets.QLayout.SetMaximumSize)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.groupBox_2 = QtWidgets.QGroupBox(self.Widget)
        self.groupBox_2.setStyleSheet("QGroupBox {\n"
"    border: 1px solid gray;\n"
"    border-radius: 9px;\n"
"    margin-top: 0.5em;\n"
"}\n"
"\n"
"QGroupBox::title {\n"
"    subcontrol-origin: margin;\n"
"    left: 10px;\n"
"    padding: 0 3px 0 3px;\n"
"}")
        self.groupBox_2.setObjectName("groupBox_2")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.groupBox_2)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.groupBox_3 = QtWidgets.QGroupBox(self.groupBox_2)
        self.groupBox_3.setObjectName("groupBox_3")
        self.gridLayout_5 = QtWidgets.QGridLayout(self.groupBox_3)
        self.gridLayout_5.setObjectName("gridLayout_5")
        self.label_6 = QtWidgets.QLabel(self.groupBox_3)
        self.label_6.setObjectName("label_6")
        self.gridLayout_5.addWidget(self.label_6, 0, 0, 1, 1)
        self.label_8 = QtWidgets.QLabel(self.groupBox_3)
        self.label_8.setObjectName("label_8")
        self.gridLayout_5.addWidget(self.label_8, 1, 0, 1, 1)
        self.bsdaL0Label = QtWidgets.QLabel(self.groupBox_3)
        self.bsdaL0Label.setStyleSheet("color: red;")
        self.bsdaL0Label.setObjectName("bsdaL0Label")
        self.gridLayout_5.addWidget(self.bsdaL0Label, 0, 1, 1, 1)
        self.bsdaL1Label = QtWidgets.QLabel(self.groupBox_3)
        self.bsdaL1Label.setStyleSheet("color: red;")
        self.bsdaL1Label.setObjectName("bsdaL1Label")
        self.gridLayout_5.addWidget(self.bsdaL1Label, 1, 1, 1, 1)
        self.label_10 = QtWidgets.QLabel(self.groupBox_3)
        self.label_10.setObjectName("label_10")
        self.gridLayout_5.addWidget(self.label_10, 2, 0, 1, 1)
        self.bsdaL2Label = QtWidgets.QLabel(self.groupBox_3)
        self.bsdaL2Label.setStyleSheet("color: red;")
        self.bsdaL2Label.setObjectName("bsdaL2Label")
        self.gridLayout_5.addWidget(self.bsdaL2Label, 2, 1, 1, 1)
        self.gridLayout_3.addWidget(self.groupBox_3, 4, 0, 1, 2)
        self.label_18 = QtWidgets.QLabel(self.groupBox_2)
        self.label_18.setObjectName("label_18")
        self.gridLayout_3.addWidget(self.label_18, 1, 0, 1, 1)
        self.label_20 = QtWidgets.QLabel(self.groupBox_2)
        self.label_20.setObjectName("label_20")
        self.gridLayout_3.addWidget(self.label_20, 2, 0, 1, 1)
        self.label_ebi_left_status = QtWidgets.QLabel(self.groupBox_2)
        self.label_ebi_left_status.setStyleSheet("color: red;")
        self.label_ebi_left_status.setObjectName("label_ebi_left_status")
        self.gridLayout_3.addWidget(self.label_ebi_left_status, 0, 1, 1, 1)
        self.label_ebi_left_version = QtWidgets.QLabel(self.groupBox_2)
        self.label_ebi_left_version.setObjectName("label_ebi_left_version")
        self.gridLayout_3.addWidget(self.label_ebi_left_version, 2, 1, 1, 1)
        self.label_2 = QtWidgets.QLabel(self.groupBox_2)
        self.label_2.setObjectName("label_2")
        self.gridLayout_3.addWidget(self.label_2, 0, 0, 1, 1)
        self.label_ebi_left_git = QtWidgets.QLabel(self.groupBox_2)
        self.label_ebi_left_git.setObjectName("label_ebi_left_git")
        self.gridLayout_3.addWidget(self.label_ebi_left_git, 1, 1, 1, 1)
        spacerItem = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.MinimumExpanding)
        self.gridLayout_3.addItem(spacerItem, 3, 0, 1, 2)
        self.horizontalLayout.addWidget(self.groupBox_2)
        self.groupBox = QtWidgets.QGroupBox(self.Widget)
        self.groupBox.setStyleSheet("QGroupBox {\n"
"    border: 1px solid gray;\n"
"    border-radius: 9px;\n"
"    margin-top: 0.5em;\n"
"}\n"
"\n"
"QGroupBox::title {\n"
"    subcontrol-origin: margin;\n"
"    left: 10px;\n"
"    padding: 0 3px 0 3px;\n"
"}")
        self.groupBox.setObjectName("groupBox")
        self.gridLayout_4 = QtWidgets.QGridLayout(self.groupBox)
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.label_22 = QtWidgets.QLabel(self.groupBox)
        self.label_22.setObjectName("label_22")
        self.gridLayout_4.addWidget(self.label_22, 1, 0, 1, 1)
        self.label_24 = QtWidgets.QLabel(self.groupBox)
        self.label_24.setObjectName("label_24")
        self.gridLayout_4.addWidget(self.label_24, 2, 0, 1, 1)
        self.label_3 = QtWidgets.QLabel(self.groupBox)
        self.label_3.setObjectName("label_3")
        self.gridLayout_4.addWidget(self.label_3, 0, 0, 1, 1)
        self.groupBox_4 = QtWidgets.QGroupBox(self.groupBox)
        self.groupBox_4.setObjectName("groupBox_4")
        self.gridLayout_6 = QtWidgets.QGridLayout(self.groupBox_4)
        self.gridLayout_6.setObjectName("gridLayout_6")
        self.label_13 = QtWidgets.QLabel(self.groupBox_4)
        self.label_13.setObjectName("label_13")
        self.gridLayout_6.addWidget(self.label_13, 0, 0, 1, 1)
        self.bsdaR0Label = QtWidgets.QLabel(self.groupBox_4)
        self.bsdaR0Label.setStyleSheet("color: red;")
        self.bsdaR0Label.setObjectName("bsdaR0Label")
        self.gridLayout_6.addWidget(self.bsdaR0Label, 0, 1, 1, 1)
        self.label_15 = QtWidgets.QLabel(self.groupBox_4)
        self.label_15.setObjectName("label_15")
        self.gridLayout_6.addWidget(self.label_15, 1, 0, 1, 1)
        self.bsdaR1Label = QtWidgets.QLabel(self.groupBox_4)
        self.bsdaR1Label.setStyleSheet("color: red;")
        self.bsdaR1Label.setObjectName("bsdaR1Label")
        self.gridLayout_6.addWidget(self.bsdaR1Label, 1, 1, 1, 1)
        self.label_17 = QtWidgets.QLabel(self.groupBox_4)
        self.label_17.setObjectName("label_17")
        self.gridLayout_6.addWidget(self.label_17, 2, 0, 1, 1)
        self.bsdaR2Label = QtWidgets.QLabel(self.groupBox_4)
        self.bsdaR2Label.setStyleSheet("color: red;")
        self.bsdaR2Label.setObjectName("bsdaR2Label")
        self.gridLayout_6.addWidget(self.bsdaR2Label, 2, 1, 1, 1)
        self.gridLayout_4.addWidget(self.groupBox_4, 4, 0, 1, 2)
        self.label_ebi_right_version = QtWidgets.QLabel(self.groupBox)
        self.label_ebi_right_version.setObjectName("label_ebi_right_version")
        self.gridLayout_4.addWidget(self.label_ebi_right_version, 2, 1, 1, 1)
        self.label_ebi_right_status = QtWidgets.QLabel(self.groupBox)
        self.label_ebi_right_status.setStyleSheet("color: red;")
        self.label_ebi_right_status.setObjectName("label_ebi_right_status")
        self.gridLayout_4.addWidget(self.label_ebi_right_status, 0, 1, 1, 1)
        self.label_ebi_right_git = QtWidgets.QLabel(self.groupBox)
        self.label_ebi_right_git.setObjectName("label_ebi_right_git")
        self.gridLayout_4.addWidget(self.label_ebi_right_git, 1, 1, 1, 1)
        spacerItem1 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.MinimumExpanding)
        self.gridLayout_4.addItem(spacerItem1, 3, 0, 1, 2)
        self.horizontalLayout.addWidget(self.groupBox)
        self.verticalLayout.addLayout(self.horizontalLayout)
        spacerItem2 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Maximum)
        self.verticalLayout.addItem(spacerItem2)
        self.groupBox_5 = QtWidgets.QGroupBox(self.Widget)
        self.groupBox_5.setStyleSheet("QGroupBox {\n"
"    border: 1px solid gray;\n"
"    border-radius: 9px;\n"
"    margin-top: 0.5em;\n"
"}\n"
"\n"
"QGroupBox::title {\n"
"    subcontrol-origin: margin;\n"
"    left: 10px;\n"
"    padding: 0 3px 0 3px;\n"
"}")
        self.groupBox_5.setFlat(False)
        self.groupBox_5.setObjectName("groupBox_5")
        self.gridLayout_7 = QtWidgets.QGridLayout(self.groupBox_5)
        self.gridLayout_7.setSizeConstraint(QtWidgets.QLayout.SetMaximumSize)
        self.gridLayout_7.setObjectName("gridLayout_7")
        self.groupBox_7 = QtWidgets.QGroupBox(self.groupBox_5)
        self.groupBox_7.setObjectName("groupBox_7")
        self.gridLayout_9 = QtWidgets.QGridLayout(self.groupBox_7)
        self.gridLayout_9.setObjectName("gridLayout_9")
        self.label_21 = QtWidgets.QLabel(self.groupBox_7)
        self.label_21.setObjectName("label_21")
        self.gridLayout_9.addWidget(self.label_21, 0, 0, 1, 1)
        self.erFramePeriodMsSpinBox = QtWidgets.QSpinBox(self.groupBox_7)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.erFramePeriodMsSpinBox.sizePolicy().hasHeightForWidth())
        self.erFramePeriodMsSpinBox.setSizePolicy(sizePolicy)
        self.erFramePeriodMsSpinBox.setButtonSymbols(QtWidgets.QAbstractSpinBox.PlusMinus)
        self.erFramePeriodMsSpinBox.setObjectName("erFramePeriodMsSpinBox")
        self.gridLayout_9.addWidget(self.erFramePeriodMsSpinBox, 0, 1, 1, 2)
        self.label_25 = QtWidgets.QLabel(self.groupBox_7)
        self.label_25.setObjectName("label_25")
        self.gridLayout_9.addWidget(self.label_25, 1, 0, 1, 2)
        self.erTemperaturePeriodMsSpinBox = QtWidgets.QSpinBox(self.groupBox_7)
        self.erTemperaturePeriodMsSpinBox.setButtonSymbols(QtWidgets.QAbstractSpinBox.PlusMinus)
        self.erTemperaturePeriodMsSpinBox.setMaximum(65535)
        self.erTemperaturePeriodMsSpinBox.setSingleStep(10)
        self.erTemperaturePeriodMsSpinBox.setObjectName("erTemperaturePeriodMsSpinBox")
        self.gridLayout_9.addWidget(self.erTemperaturePeriodMsSpinBox, 1, 2, 1, 1)
        self.groupBox_9 = QtWidgets.QGroupBox(self.groupBox_7)
        self.groupBox_9.setObjectName("groupBox_9")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.groupBox_9)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.bsdaR0checkBox = QtWidgets.QCheckBox(self.groupBox_9)
        self.bsdaR0checkBox.setObjectName("bsdaR0checkBox")
        self.verticalLayout_3.addWidget(self.bsdaR0checkBox)
        self.bsdaR1checkBox = QtWidgets.QCheckBox(self.groupBox_9)
        self.bsdaR1checkBox.setObjectName("bsdaR1checkBox")
        self.verticalLayout_3.addWidget(self.bsdaR1checkBox)
        self.bsdaR2checkBox = QtWidgets.QCheckBox(self.groupBox_9)
        self.bsdaR2checkBox.setObjectName("bsdaR2checkBox")
        self.verticalLayout_3.addWidget(self.bsdaR2checkBox)
        self.gridLayout_9.addWidget(self.groupBox_9, 2, 0, 1, 3)
        self.gridLayout_7.addWidget(self.groupBox_7, 8, 2, 1, 1)
        self.frameDurationUsSpinBox = QtWidgets.QSpinBox(self.groupBox_5)
        self.frameDurationUsSpinBox.setButtonSymbols(QtWidgets.QAbstractSpinBox.PlusMinus)
        self.frameDurationUsSpinBox.setMaximum(1000)
        self.frameDurationUsSpinBox.setSingleStep(10)
        self.frameDurationUsSpinBox.setObjectName("frameDurationUsSpinBox")
        self.gridLayout_7.addWidget(self.frameDurationUsSpinBox, 5, 2, 1, 1)
        self.label_5 = QtWidgets.QLabel(self.groupBox_5)
        self.label_5.setObjectName("label_5")
        self.gridLayout_7.addWidget(self.label_5, 6, 1, 1, 1)
        self.label_4 = QtWidgets.QLabel(self.groupBox_5)
        self.label_4.setObjectName("label_4")
        self.gridLayout_7.addWidget(self.label_4, 5, 1, 1, 1)
        self.groupBox_6 = QtWidgets.QGroupBox(self.groupBox_5)
        self.groupBox_6.setObjectName("groupBox_6")
        self.gridLayout_8 = QtWidgets.QGridLayout(self.groupBox_6)
        self.gridLayout_8.setObjectName("gridLayout_8")
        self.label_19 = QtWidgets.QLabel(self.groupBox_6)
        self.label_19.setObjectName("label_19")
        self.gridLayout_8.addWidget(self.label_19, 0, 0, 1, 1)
        self.elTemperaturePeriodMsSpinBox = QtWidgets.QSpinBox(self.groupBox_6)
        self.elTemperaturePeriodMsSpinBox.setButtonSymbols(QtWidgets.QAbstractSpinBox.PlusMinus)
        self.elTemperaturePeriodMsSpinBox.setMaximum(65535)
        self.elTemperaturePeriodMsSpinBox.setSingleStep(10)
        self.elTemperaturePeriodMsSpinBox.setObjectName("elTemperaturePeriodMsSpinBox")
        self.gridLayout_8.addWidget(self.elTemperaturePeriodMsSpinBox, 1, 1, 1, 1)
        self.elFramePeriodMsSpinBox = QtWidgets.QSpinBox(self.groupBox_6)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.elFramePeriodMsSpinBox.sizePolicy().hasHeightForWidth())
        self.elFramePeriodMsSpinBox.setSizePolicy(sizePolicy)
        self.elFramePeriodMsSpinBox.setButtonSymbols(QtWidgets.QAbstractSpinBox.PlusMinus)
        self.elFramePeriodMsSpinBox.setObjectName("elFramePeriodMsSpinBox")
        self.gridLayout_8.addWidget(self.elFramePeriodMsSpinBox, 0, 1, 1, 1)
        self.label_23 = QtWidgets.QLabel(self.groupBox_6)
        self.label_23.setObjectName("label_23")
        self.gridLayout_8.addWidget(self.label_23, 1, 0, 1, 1)
        self.groupBox_8 = QtWidgets.QGroupBox(self.groupBox_6)
        self.groupBox_8.setObjectName("groupBox_8")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.groupBox_8)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.bsdaL0checkBox = QtWidgets.QCheckBox(self.groupBox_8)
        self.bsdaL0checkBox.setObjectName("bsdaL0checkBox")
        self.verticalLayout_2.addWidget(self.bsdaL0checkBox)
        self.bsdaL1checkBox = QtWidgets.QCheckBox(self.groupBox_8)
        self.bsdaL1checkBox.setObjectName("bsdaL1checkBox")
        self.verticalLayout_2.addWidget(self.bsdaL1checkBox)
        self.bsdaL2checkBox = QtWidgets.QCheckBox(self.groupBox_8)
        self.bsdaL2checkBox.setObjectName("bsdaL2checkBox")
        self.verticalLayout_2.addWidget(self.bsdaL2checkBox)
        self.gridLayout_8.addWidget(self.groupBox_8, 2, 0, 1, 1)
        self.gridLayout_7.addWidget(self.groupBox_6, 8, 1, 1, 1)
        self.enableTemperatureCheckBox = QtWidgets.QCheckBox(self.groupBox_5)
        self.enableTemperatureCheckBox.setObjectName("enableTemperatureCheckBox")
        self.gridLayout_7.addWidget(self.enableTemperatureCheckBox, 0, 1, 1, 1)
        self.temperaturePeriodMsSpinBox = QtWidgets.QSpinBox(self.groupBox_5)
        self.temperaturePeriodMsSpinBox.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.temperaturePeriodMsSpinBox.setButtonSymbols(QtWidgets.QAbstractSpinBox.PlusMinus)
        self.temperaturePeriodMsSpinBox.setMaximum(90000)
        self.temperaturePeriodMsSpinBox.setSingleStep(100)
        self.temperaturePeriodMsSpinBox.setObjectName("temperaturePeriodMsSpinBox")
        self.gridLayout_7.addWidget(self.temperaturePeriodMsSpinBox, 6, 2, 1, 1)
        self.enableLightCheckBox = QtWidgets.QCheckBox(self.groupBox_5)
        self.enableLightCheckBox.setObjectName("enableLightCheckBox")
        self.gridLayout_7.addWidget(self.enableLightCheckBox, 3, 1, 1, 1)
        self.enableImuCheckBox = QtWidgets.QCheckBox(self.groupBox_5)
        self.enableImuCheckBox.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.enableImuCheckBox.setAutoFillBackground(False)
        self.enableImuCheckBox.setObjectName("enableImuCheckBox")
        self.gridLayout_7.addWidget(self.enableImuCheckBox, 2, 1, 1, 1)
        self.framingTypeComboBox = QtWidgets.QComboBox(self.groupBox_5)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.framingTypeComboBox.sizePolicy().hasHeightForWidth())
        self.framingTypeComboBox.setSizePolicy(sizePolicy)
        self.framingTypeComboBox.setObjectName("framingTypeComboBox")
        self.framingTypeComboBox.addItem("")
        self.framingTypeComboBox.addItem("")
        self.framingTypeComboBox.addItem("")
        self.framingTypeComboBox.addItem("")
        self.framingTypeComboBox.addItem("")
        self.gridLayout_7.addWidget(self.framingTypeComboBox, 4, 2, 1, 1)
        self.label_26 = QtWidgets.QLabel(self.groupBox_5)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_26.sizePolicy().hasHeightForWidth())
        self.label_26.setSizePolicy(sizePolicy)
        self.label_26.setObjectName("label_26")
        self.gridLayout_7.addWidget(self.label_26, 4, 1, 1, 1)
        self.verticalLayout.addWidget(self.groupBox_5)
        self.gridLayout_2.addLayout(self.verticalLayout, 0, 2, 2, 1)
        spacerItem3 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_2.addItem(spacerItem3, 0, 1, 2, 1)
        self.gridLayout = QtWidgets.QGridLayout()
        self.gridLayout.setSizeConstraint(QtWidgets.QLayout.SetFixedSize)
        self.gridLayout.setObjectName("gridLayout")
        self.connectCdmButton = QtWidgets.QPushButton(self.Widget)
        self.connectCdmButton.setMinimumSize(QtCore.QSize(0, 33))
        self.connectCdmButton.setObjectName("connectCdmButton")
        self.gridLayout.addWidget(self.connectCdmButton, 2, 0, 1, 2)
        self.serverEdit = QtWidgets.QLineEdit(self.Widget)
        self.serverEdit.setObjectName("serverEdit")
        self.gridLayout.addWidget(self.serverEdit, 0, 1, 1, 1)
        self.startButton = QtWidgets.QPushButton(self.Widget)
        self.startButton.setEnabled(False)
        self.startButton.setMinimumSize(QtCore.QSize(0, 33))
        self.startButton.setObjectName("startButton")
        self.gridLayout.addWidget(self.startButton, 8, 0, 1, 2)
        self.stopButton = QtWidgets.QPushButton(self.Widget)
        self.stopButton.setEnabled(False)
        self.stopButton.setMinimumSize(QtCore.QSize(0, 33))
        self.stopButton.setObjectName("stopButton")
        self.gridLayout.addWidget(self.stopButton, 9, 0, 1, 2)
        spacerItem4 = QtWidgets.QSpacerItem(20, 423, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Ignored)
        self.gridLayout.addItem(spacerItem4, 3, 0, 1, 2)
        self.svgContainer = QtWidgets.QWidget(self.Widget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.svgContainer.sizePolicy().hasHeightForWidth())
        self.svgContainer.setSizePolicy(sizePolicy)
        self.svgContainer.setMinimumSize(QtCore.QSize(250, 250))
        self.svgContainer.setBaseSize(QtCore.QSize(100, 100))
        self.svgContainer.setObjectName("svgContainer")
        self.gridLayout_10 = QtWidgets.QGridLayout(self.svgContainer)
        self.gridLayout_10.setSizeConstraint(QtWidgets.QLayout.SetDefaultConstraint)
        self.gridLayout_10.setObjectName("gridLayout_10")
        self.gridLayout.addWidget(self.svgContainer, 5, 0, 1, 2)
        self.configureButton = QtWidgets.QPushButton(self.Widget)
        self.configureButton.setEnabled(False)
        self.configureButton.setMinimumSize(QtCore.QSize(0, 33))
        self.configureButton.setObjectName("configureButton")
        self.gridLayout.addWidget(self.configureButton, 7, 0, 1, 2)
        self.label = QtWidgets.QLabel(self.Widget)
        self.label.setObjectName("label")
        self.gridLayout.addWidget(self.label, 0, 0, 1, 1)
        self.connectEbiButton = QtWidgets.QPushButton(self.Widget)
        self.connectEbiButton.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.connectEbiButton.sizePolicy().hasHeightForWidth())
        self.connectEbiButton.setSizePolicy(sizePolicy)
        self.connectEbiButton.setMinimumSize(QtCore.QSize(0, 33))
        self.connectEbiButton.setObjectName("connectEbiButton")
        self.gridLayout.addWidget(self.connectEbiButton, 6, 0, 1, 1)
        self.disconnectEbiButton = QtWidgets.QPushButton(self.Widget)
        self.disconnectEbiButton.setEnabled(False)
        self.disconnectEbiButton.setMinimumSize(QtCore.QSize(0, 33))
        self.disconnectEbiButton.setObjectName("disconnectEbiButton")
        self.gridLayout.addWidget(self.disconnectEbiButton, 6, 1, 1, 1)
        self.gridLayout_2.addLayout(self.gridLayout, 0, 0, 2, 1)
        MainWindow.setCentralWidget(self.Widget)
        self.statusBar = QtWidgets.QStatusBar(MainWindow)
        self.statusBar.setObjectName("statusBar")
        MainWindow.setStatusBar(self.statusBar)

        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        self.Widget.setWindowTitle(_translate("MainWindow", "Widget"))
        self.groupBox_2.setTitle(_translate("MainWindow", "Ebi Left"))
        self.groupBox_3.setTitle(_translate("MainWindow", "BSDAs"))
        self.label_6.setText(_translate("MainWindow", "L0:"))
        self.label_8.setText(_translate("MainWindow", "L1:"))
        self.bsdaL0Label.setText(_translate("MainWindow", "DISCONNECTED"))
        self.bsdaL1Label.setText(_translate("MainWindow", "DISCONNECTED"))
        self.label_10.setText(_translate("MainWindow", "L2:"))
        self.bsdaL2Label.setText(_translate("MainWindow", "DISCONNECTED"))
        self.label_18.setText(_translate("MainWindow", "Git:"))
        self.label_20.setText(_translate("MainWindow", "Version:"))
        self.label_ebi_left_status.setText(_translate("MainWindow", "DISCONNECTED"))
        self.label_ebi_left_version.setText(_translate("MainWindow", "NOE"))
        self.label_2.setText(_translate("MainWindow", "Status:"))
        self.label_ebi_left_git.setText(_translate("MainWindow", "NONE"))
        self.groupBox.setTitle(_translate("MainWindow", "Ebi Right"))
        self.label_22.setText(_translate("MainWindow", "Git:"))
        self.label_24.setText(_translate("MainWindow", "Version:"))
        self.label_3.setText(_translate("MainWindow", "Status:"))
        self.groupBox_4.setTitle(_translate("MainWindow", "BSDAs"))
        self.label_13.setText(_translate("MainWindow", "R0:"))
        self.bsdaR0Label.setText(_translate("MainWindow", "DISCONNECTED"))
        self.label_15.setText(_translate("MainWindow", "R1:"))
        self.bsdaR1Label.setText(_translate("MainWindow", "DISCONNECTED"))
        self.label_17.setText(_translate("MainWindow", "R2:"))
        self.bsdaR2Label.setText(_translate("MainWindow", "DISCONNECTED"))
        self.label_ebi_right_version.setText(_translate("MainWindow", "NONE"))
        self.label_ebi_right_status.setText(_translate("MainWindow", "DISCONNECTED"))
        self.label_ebi_right_git.setText(_translate("MainWindow", "NONE"))
        self.groupBox_5.setTitle(_translate("MainWindow", "Configuration"))
        self.groupBox_7.setTitle(_translate("MainWindow", "Ebi right"))
        self.label_21.setText(_translate("MainWindow", "Frame reader period (in milliseconds): "))
        self.label_25.setText(_translate("MainWindow", "Temperature reader period (in milliseconds):"))
        self.groupBox_9.setTitle(_translate("MainWindow", "BSDAs enabled"))
        self.bsdaR0checkBox.setText(_translate("MainWindow", "R0"))
        self.bsdaR1checkBox.setText(_translate("MainWindow", "R1"))
        self.bsdaR2checkBox.setText(_translate("MainWindow", "R2"))
        self.label_5.setText(_translate("MainWindow", "BSDA temperature period (in milliseconds):"))
        self.label_4.setText(_translate("MainWindow", "BSDA frame duration (in microseconds):"))
        self.groupBox_6.setTitle(_translate("MainWindow", "Ebi left"))
        self.label_19.setText(_translate("MainWindow", "Frame reader period (in milliseconds):"))
        self.label_23.setText(_translate("MainWindow", "Temperature reader period (in milliseconds):"))
        self.groupBox_8.setTitle(_translate("MainWindow", "BSDAs enabled"))
        self.bsdaL0checkBox.setText(_translate("MainWindow", "L0"))
        self.bsdaL1checkBox.setText(_translate("MainWindow", "L1"))
        self.bsdaL2checkBox.setText(_translate("MainWindow", "L2"))
        self.enableTemperatureCheckBox.setText(_translate("MainWindow", "Enable temperature reading"))
        self.enableLightCheckBox.setText(_translate("MainWindow", "Enable light reading"))
        self.enableImuCheckBox.setText(_translate("MainWindow", "Enable IMU"))
        self.framingTypeComboBox.setItemText(0, _translate("MainWindow", "Full "))
        self.framingTypeComboBox.setItemText(1, _translate("MainWindow", "Sum"))
        self.framingTypeComboBox.setItemText(2, _translate("MainWindow", "Sum squared"))
        self.framingTypeComboBox.setItemText(3, _translate("MainWindow", "Histogram"))
        self.framingTypeComboBox.setItemText(4, _translate("MainWindow", "Test"))
        self.label_26.setText(_translate("MainWindow", "Framing type:"))
        self.connectCdmButton.setText(_translate("MainWindow", "Connect to CDM"))
        self.startButton.setText(_translate("MainWindow", "Start"))
        self.stopButton.setText(_translate("MainWindow", "Stop"))
        self.configureButton.setText(_translate("MainWindow", "Configure"))
        self.label.setText(_translate("MainWindow", "CDM Server"))
        self.connectEbiButton.setText(_translate("MainWindow", "Connect to EBIs"))
        self.disconnectEbiButton.setText(_translate("MainWindow", "Disconnect from EBI"))
